# Doomswiping

## I will profiter

One of the words that's stuck out to me learning French is the verb _profiter_, or _to profit_.
The direct translation is easy - English and French have substantial shared lineage, and this is a word that's unchanged between the two.
The usage and connotation of the word between the two languages does differ, however, and I'd like to explore the many senses of the word(s) for a spell.

In English, 'to profit' is more often than not associated with financial or economic contexts.
If one profits from something, they've made money from it, they've got out more than they put in, they've made a worthwhile exchange.
It is generally used in discussions of wealth, ventures, or commercially applied in business.

In French, _profiter_ means the same thing, but has a much weaker financial connotation.
Rather, it is associated with personal gain in terms of character growth, positive experiences, improved well-being.
For example, « *profite bien de tes vacances* » directly translates to "profit well of your holidays", but the meaning is closer to "enjoy your holidays".

In English, we are unlikely to talk of profiting from a holiday, or of a positive personal experience, although it makes perfect grammatical sense.
We'd understand someone's use of the word in this sense, though we'd think it an odd turn of phrase.
I think there is something of a knife-edge here, an unstable equilibrium where the same concept resolves to fundamentally different meanings depending on one's own native culture and experience.

---

A well-worn idiom in English is that time is money.
This makes perfect sense in a commercial setting: our economonic systems prize cost-efficiency and reward those that make the most with the least.
This is also true in biology; natural selection optimises and specialises organisms to be the best in their niche, and everything else is made extinct.
In the case of the individual, we could apply the same calculus: our lives each have a finite budget of time available, so it follows that we should optimise how to spend it in order to gain the most utility, whatever that may mean for us each individually.

This is the value proposition put forward by industries like match-making (Hinge), ready-made food delivery (HelloFresh), or educational course providers (Udemy).
Generally, they provide a means by which to do something one could already do, but with a much reduced time investment.
There's evidently demand for these industries, and undoubtedly they provide a service that's valued by some segment of the population, so I won't tilt against windmills decrying their existence here.
However, I think there's cause for concern with such time-optimisation.

Take strategies for meeting people to date, for example.
If I use a match-making service, I indicate preference towards some individuals, while they do the same to me and others, and some algorithm tries to match us up with people it thinks we'll like.
If a match is made, we talk, and can arrange to meet up, and from there, perhaps on to form whatever kind of relationship it is we are looking for.
This is straightforward and convenient.

If instead I rely on meeting people by chance, I have to regularly encounter situations in which I am likely to meet people.
I have to additionally hope that those people will be the kinds of people I am likely to get along with, and that they are also looking to meet new people.
I also have to be someone that is interesting enough in a chance encounter that someone I meet would like to see me again.
This is deeply complex, massively daunting, and extremely time-consuming.

It would seem therefore that dating apps are a much better time investment.
Instead of having to figure out things to do or places to go, presumably spend money to enable the ordeal, I can instead look for a date while in the midst of the rest of my daily life.
I know that the people I see there are interested, broadly speaking, in the same thing as me, and can precisely tune my preferences.
It should work out that not only do I spend less time looking for someone, I also find someone that is likely to closely match myself.
Therefore, using a dating application is a much better use of my time!

Or is it?

I think there's a flaw here in how we've valued our time.
Time we've put into our app is time spent we've spent directly pursuing a goal: "I want to find a relationship".
We've done this efficiently, as the application should optimise our time spent by matching us directly with people, and we're free to spend as much or as little time as we would like.
But there are several problems with this thinking: we're trusting the application's ability to find something we value; we're assuming our goal can be directly approached; and we're valuing our time in relation to having achieved this goal.
We'll examine the application first.

## Profiles aren't people

First, it should be re-iterated that when you're using a dating app, you are not looking at people.
You are looking at people's *profiles*, which I would argue are actually very poor indications of what the people behind them are like.
It's well-documented that people don't represent themselves honestly on online platforms, and it would be unreasonable to expect them to.

A profile also acts as a filter designed by whatever particular platform you happen to be using, restricting someone to share themselves in a specific format, which further limits any genuine self-expression someone can display.
This will probably act to negate some of the platform's matching ability.

We also should consider our own biases; applications will allow you to set an age range, political preferences, drink and drug tolerance, religious view, et cetera.
In plenty of cases this is perfectly reasonable, but isn't it also easy to see how this enables a user to set their own expectations unreasonably high?
This too, will reduce the algorithm's ability to match effectively.

Humans did not evolve for a digital existence, and relationships are comprehensively _not_ digital.
We evolved to have rich and complex social interactions, as our survival on the savannah depended on it.
We track each others' posture, tone, facial expressions, and keep tabs on the interactions between others that aren't ourselves, almost entirely automatically.

None of these values can be meaningfully put into a dating profile.
Even though they're perfectly available from the first date onwards, at that point you've committed your time and energy to something with a pretty low chance of working out - exactly what you wanted to avoid in the first place!

We also run the risk of cognitive exhaustion.
Thought profiles aren't people, the parts of our brains that deal with faces don't know that, and will still be running full-tilt as we swipe onwards.
This processing itself takes energy, and is the social equivalent of junk food, because there's no actual socialising backing it up.

Instead, by increasing the number of people we're likely to meet day-to-day, we give our honed social instincts more opportunity to do what they're there to do.
By training them on lots of people, we'll get a better sense of what it is we're after in the first place.
It's more effort to organise and to engage in, but it's certainly better for us overall.

## Pursue goals indirectly

Let's re-examine the things we have to do to meet people by chance: encounter new situations with new pople in them, go somewhere that I'd like to be, and be approachable and charming.
Put this way, don't these maybe sound like goals on their own?

We could directly pursue those other goals, which don't require any chance.
We each know where we could go to encounter new situations, and if we don't, we could probably find out if we applied ourselves to the problem.
We each have our insecurities we'd like to work on, to become more confident and outgoing.
Especially after an isolating pandemic we likely all need the face-to-face practice of being where people are anyway.

I think that directly pursuing a goal like "I want to find a relationship" is something of a façade.
Achieving it inherently depends on another person (who cannot be controlled) and the circumstances under which we find ourselves together (even in the best case, we need to be lucky).
That chance aspect is what makes dating so difficult, but also what makes it so rewarding.

## Saving time

Finally, let's examine the time spent on the application itself.
It's true that, like any number of modern mobile apps, the minimum time investement is very low.
You can set up a profile in minutes, and from there you can view profiles on the train, in the coffee queue, or taking a dump.
Because it's so easy to do, it means that *you do it easily*.

Most of us are already chronic smartphone users, and I absolutely count myself among them. 
It's devastatingly easy to fall into a habit, and once a habit is dug in it will begin to effect how you think.
What started as a canny time saving becomes a time sink in itself. 
Not only that, but it also expends our valuable energy making what are ultimately low-value decisions, culminating in decision fatigue.
A decision-fatigued person no longer has the energy to make energy choices, and so will but succumb to their habits more, reinforcing a vicious, energy-sapping cycle.

I've seen plenty of people find meaningful relationships through dating apps, and I think that's great: it's always nice to see technology bringing people together.
But any technology has a dark side, and in my personal experience I've seen more of that than the positive with match-makers and other time-saving propositions.
As a result of that, I tend to prefer old-fi approaches when they're available.

One could argue quite reasonably that the slow path is wasting time, but I think that's a matter of how one frames it.
Any time you enjoyed, and look back on after as having enjoyed, surely wasn't wasted.
If I'm taken the "optimised" path, I might be missing out on enjoying the thing in the first place, and if I'm not enjoying it, I can only wonder if I'm missing the point entirely.

---

I didn't reference anything directly, but there are a few books I've been thinking about which motivated this point of view. They are:

* [You Are Not A Gadget](https://www.goodreads.com/en/book/show/6683549-you-are-not-a-gadget)
* [Homo Deus](https://www.goodreads.com/book/show/31138556-homo-deus)
* [Zen and The Art of Motorcycle Maintenance](https://www.goodreads.com/book/show/19438058-zen-and-the-art-of-motorcycle-maintenance)
